@@ -12,10 +12,15 @@ plot.rma.uni <- function(x, qqplot=FALSE, ...) {
    if (!is.element(na.act, c("na.omit", "na.exclude", "na.fail", "na.pass")))
       stop(mstyle$stop("Unknown 'na.action' specified under options()."))
 
+   .start.plot()
+
    par.mfrow <- par("mfrow")
    par(mfrow=c(2,2))
    on.exit(par(mfrow = par.mfrow), add=TRUE)
 
+   bg <- .coladj(par("bg","fg"), dark=0.35, light=-0.35)
+   col.na <- .coladj(par("bg","fg"), dark=0.2, light=-0.2)
+
    #########################################################################
 
    if (x$int.only) {
@@ -61,9 +66,9 @@ plot.rma.uni <- function(x, qqplot=FALSE, ...) {
          k <- length(z)
 
          plot(NA, NA, xlim=c(1,k), ylim=c(min(z, -2, na.rm=TRUE), max(z, 2, na.rm=TRUE)), xaxt="n", xlab="Study", ylab="", bty="l", ...)
-         lines(seq_len(k)[not.na], z[not.na], col="lightgray", ...)
+         lines(seq_len(k)[not.na], z[not.na], col=col.na, ...)
          lines(seq_len(k), z, ...)
-         points(x=seq_len(k), y=z, pch=21, bg="black", ...)
+         points(x=seq_len(k), y=z, pch=21, bg=bg, ...)
          axis(side=1, at=seq_len(k), labels=ids, ...)
          abline(h=0, lty="dashed", ...)
          abline(h=c(qnorm(.025),qnorm(.975)), lty="dotted", ...)
@@ -91,9 +96,10 @@ plot.rma.uni <- function(x, qqplot=FALSE, ...) {
       pred <- fitted(x)
       options(na.action = na.act)
 
-      plot(pred, z, ylim=c(min(z, -2, na.rm=TRUE), max(z, 2, na.rm=TRUE)), pch=19, bty="l", xlab="Fitted Value", ylab="Standardized Residual", ...)
+      plot(NA, NA, xlim=range(pred), ylim=c(min(z, -2, na.rm=TRUE), max(z, 2, na.rm=TRUE)), bty="l", xlab="Fitted Value", ylab="Standardized Residual", ...)
       abline(h=0, lty="dashed", ...)
       abline(h=c(qnorm(.025),qnorm(.975)), lty="dotted", ...)
+      points(pred, z, pch=21, bg=bg, ...)
       title("Fitted vs. Standardized Residuals", ...)
 
       ######################################################################
@@ -122,9 +128,9 @@ plot.rma.uni <- function(x, qqplot=FALSE, ...) {
          k <- length(z)
 
          plot(NA, NA, xlim=c(1,k), ylim=c(min(z, -2, na.rm=TRUE), max(z, 2, na.rm=TRUE)), xaxt="n", xlab="Study", ylab="", bty="l", ...)
-         lines(seq_len(k)[not.na], z[not.na], col="lightgray", ...)
+         lines(seq_len(k)[not.na], z[not.na], col=col.na, ...)
          lines(seq_len(k), z, ...)
-         points(x=seq_len(k), y=z, pch=21, bg="black", ...)
+         points(x=seq_len(k), y=z, pch=21, bg=bg, ...)
          axis(side=1, at=seq_len(k), labels=ids, ...)
          abline(h=0, lty="dashed", ...)
          abline(h=c(qnorm(.025),qnorm(.975)), lty="dotted", ...)
